Class: Google::Apis::AdmobV1::AppManualAppInfo
- Inherits:
-
Object
- Object
- Google::Apis::AdmobV1::AppManualAppInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admob_v1/classes.rb,
lib/google/apis/admob_v1/representations.rb,
lib/google/apis/admob_v1/representations.rb
Overview
Information provided for manual apps which are not linked to an application store (Example: Google Play, App Store).
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the app as shown in the AdMob UI, which is provided by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppManualAppInfo
constructor
A new instance of AppManualAppInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppManualAppInfo
Returns a new instance of AppManualAppInfo.
184 185 186 |
# File 'lib/google/apis/admob_v1/classes.rb', line 184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The display name of the app as shown in the AdMob UI, which is provided by the
user. The maximum length allowed is 80 characters.
Corresponds to the JSON property displayName
182 183 184 |
# File 'lib/google/apis/admob_v1/classes.rb', line 182 def display_name @display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
189 190 191 |
# File 'lib/google/apis/admob_v1/classes.rb', line 189 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) end |