Class: Google::Apis::AdmobV1::GenerateMediationReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1/classes.rb,
lib/google/apis/admob_v1/representations.rb,
lib/google/apis/admob_v1/representations.rb

Overview

The streaming response for the AdMob Mediation report where the first response contains the report header, then a stream of row responses, and finally a footer as the last response message. For example: ["header": "date_range": "start_date":"year": 2018, "month": 9, "day": 1, "end_date":"year": 2018, "month": 9, "day": 1, "localization_settings": "currency_code": " USD", "language_code": "en-US" , "row": "dimension_values": "DATE": "value": "20180918", "APP": "value": "ca-app-pub-8123415297019784~ 1001342552", "display_label": "My app name!" , "metric_values": " ESTIMATED_EARNINGS":"decimal_value": "1324746" , "footer":" matching_row_count": 1]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateMediationReportResponse

Returns a new instance of GenerateMediationReportResponse.



335
336
337
# File 'lib/google/apis/admob_v1/classes.rb', line 335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Groups data available after report generation, for example, warnings and row counts. Always sent as the last message in the stream response. Corresponds to the JSON property footer



322
323
324
# File 'lib/google/apis/admob_v1/classes.rb', line 322

def footer
  @footer
end

#headerGoogle::Apis::AdmobV1::ReportHeader

Groups data helps to treat the generated report. Always sent as a first message in the stream response. Corresponds to the JSON property header



328
329
330
# File 'lib/google/apis/admob_v1/classes.rb', line 328

def header
  @header
end

#rowGoogle::Apis::AdmobV1::ReportRow

A row of the returning report. Corresponds to the JSON property row



333
334
335
# File 'lib/google/apis/admob_v1/classes.rb', line 333

def row
  @row
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



340
341
342
343
344
# File 'lib/google/apis/admob_v1/classes.rb', line 340

def update!(**args)
  @footer = args[:footer] if args.key?(:footer)
  @header = args[:header] if args.key?(:header)
  @row = args[:row] if args.key?(:row)
end