Class: Google::Apis::AdmobV1::NetworkReportSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1/classes.rb,
lib/google/apis/admob_v1/representations.rb,
lib/google/apis/admob_v1/representations.rb

Overview

The specification for generating an AdMob Network report. For example, the specification to get clicks and estimated earnings for only the 'US' and 'CN' countries can look like the following example: 'date_range': 'start_date': 'year': 2021, 'month': 9, 'day': 1, 'end_date': 'year': 2021, 'month': 9, ' day': 30 , 'dimensions': ['DATE', 'APP', 'COUNTRY'], 'metrics': ['CLICKS', ' ESTIMATED_EARNINGS'], 'dimension_filters': [ 'dimension': 'COUNTRY', ' matches_any': 'values': ['value': 'US', 'value': 'CN'] ], ' sort_conditions': ['dimension':'APP', order: 'ASCENDING','metric':'CLICKS' , order: 'DESCENDING'], 'localization_settings': 'currency_code': 'USD', ' language_code': 'en-US' For a better understanding, you can treat the preceding specification like the following pseudo SQL: SELECT DATE, APP, COUNTRY, CLICKS, ESTIMATED_EARNINGS FROM NETWORK_REPORT WHERE DATE >= '2021-09- 01' AND DATE <= '2021-09-30' AND COUNTRY IN ('US', 'CN') GROUP BY DATE, APP, COUNTRY ORDER BY APP ASC, CLICKS DESC;

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkReportSpec

Returns a new instance of NetworkReportSpec.



734
735
736
# File 'lib/google/apis/admob_v1/classes.rb', line 734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rangeGoogle::Apis::AdmobV1::DateRange

Specification of a single date range. Both dates are inclusive. Corresponds to the JSON property dateRange



687
688
689
# File 'lib/google/apis/admob_v1/classes.rb', line 687

def date_range
  @date_range
end

#dimension_filtersArray<Google::Apis::AdmobV1::NetworkReportSpecDimensionFilter>

Describes which report rows to match based on their dimension values. Corresponds to the JSON property dimensionFilters



692
693
694
# File 'lib/google/apis/admob_v1/classes.rb', line 692

def dimension_filters
  @dimension_filters
end

#dimensionsArray<String>

List of dimensions of the report. The value combination of these dimensions determines the row of the report. If no dimensions are specified, the report returns a single row of requested metrics for the entire account. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


699
700
701
# File 'lib/google/apis/admob_v1/classes.rb', line 699

def dimensions
  @dimensions
end

#localization_settingsGoogle::Apis::AdmobV1::LocalizationSettings

Localization settings for reports, such as currency and language. It affects how metrics are calculated. Corresponds to the JSON property localizationSettings



705
706
707
# File 'lib/google/apis/admob_v1/classes.rb', line 705

def localization_settings
  @localization_settings
end

#max_report_rowsFixnum

Maximum number of report data rows to return. If the value is not set, the API returns as many rows as possible, up to 100000. Acceptable values are 1-100000, inclusive. Values larger than 100000 return an error. Corresponds to the JSON property maxReportRows

Returns:

  • (Fixnum)


712
713
714
# File 'lib/google/apis/admob_v1/classes.rb', line 712

def max_report_rows
  @max_report_rows
end

#metricsArray<String>

List of metrics of the report. A report must specify at least one metric. Corresponds to the JSON property metrics

Returns:

  • (Array<String>)


717
718
719
# File 'lib/google/apis/admob_v1/classes.rb', line 717

def metrics
  @metrics
end

#sort_conditionsArray<Google::Apis::AdmobV1::NetworkReportSpecSortCondition>

Describes the sorting of report rows. The order of the condition in the list defines its precedence; the earlier the condition, the higher its precedence. If no sort conditions are specified, the row ordering is undefined. Corresponds to the JSON property sortConditions



724
725
726
# File 'lib/google/apis/admob_v1/classes.rb', line 724

def sort_conditions
  @sort_conditions
end

#time_zoneString

A report time zone. Accepts an IANA TZ name values, such as "America/ Los_Angeles." If no time zone is defined, the account default takes effect. Check default value by the get account action. Warning: The "America/ Los_Angeles" is the only supported value at the moment. Corresponds to the JSON property timeZone

Returns:

  • (String)


732
733
734
# File 'lib/google/apis/admob_v1/classes.rb', line 732

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



739
740
741
742
743
744
745
746
747
748
# File 'lib/google/apis/admob_v1/classes.rb', line 739

def update!(**args)
  @date_range = args[:date_range] if args.key?(:date_range)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @localization_settings = args[:localization_settings] if args.key?(:localization_settings)
  @max_report_rows = args[:max_report_rows] if args.key?(:max_report_rows)
  @metrics = args[:metrics] if args.key?(:metrics)
  @sort_conditions = args[:sort_conditions] if args.key?(:sort_conditions)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end