Class: Google::Apis::AdmobV1::ReportHeader
- Inherits:
-
Object
- Object
- Google::Apis::AdmobV1::ReportHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admob_v1/classes.rb,
lib/google/apis/admob_v1/representations.rb,
lib/google/apis/admob_v1/representations.rb
Overview
Groups data helps to treat the generated report. Always sent as a first message in the stream response.
Instance Attribute Summary collapse
-
#date_range ⇒ Google::Apis::AdmobV1::DateRange
Specification of a single date range.
-
#localization_settings ⇒ Google::Apis::AdmobV1::LocalizationSettings
Localization settings for reports, such as currency and language.
-
#reporting_time_zone ⇒ String
The report time zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportHeader
constructor
A new instance of ReportHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportHeader
Returns a new instance of ReportHeader.
900 901 902 |
# File 'lib/google/apis/admob_v1/classes.rb', line 900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date_range ⇒ Google::Apis::AdmobV1::DateRange
Specification of a single date range. Both dates are inclusive.
Corresponds to the JSON property dateRange
886 887 888 |
# File 'lib/google/apis/admob_v1/classes.rb', line 886 def date_range @date_range end |
#localization_settings ⇒ Google::Apis::AdmobV1::LocalizationSettings
Localization settings for reports, such as currency and language. It affects
how metrics are calculated.
Corresponds to the JSON property localizationSettings
892 893 894 |
# File 'lib/google/apis/admob_v1/classes.rb', line 892 def localization_settings @localization_settings end |
#reporting_time_zone ⇒ String
The report time zone. The value is a time-zone ID as specified by the CLDR
project, for example, "America/Los_Angeles".
Corresponds to the JSON property reportingTimeZone
898 899 900 |
# File 'lib/google/apis/admob_v1/classes.rb', line 898 def reporting_time_zone @reporting_time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
905 906 907 908 909 |
# File 'lib/google/apis/admob_v1/classes.rb', line 905 def update!(**args) @date_range = args[:date_range] if args.key?(:date_range) @localization_settings = args[:localization_settings] if args.key?(:localization_settings) @reporting_time_zone = args[:reporting_time_zone] if args.key?(:reporting_time_zone) end |